@@ -286,6 +286,7 @@ class Fem:
     ConstraintPressure = 'Fem::ConstraintPressure'
     ConstraintPulley = 'Fem::ConstraintPulley'
     ConstraintPython = 'Fem::ConstraintPython'
+    ConstraintSpring = 'Fem::ConstraintSpring'
     ConstraintTemperature = 'Fem::ConstraintTemperature'
     ConstraintTransform = 'Fem::ConstraintTransform'
     DocumentObject = 'Fem::DocumentObject'
@@ -341,6 +342,7 @@ class FemGui:
     ViewProviderFemConstraintPressure = 'FemGui::ViewProviderFemConstraintPressure'
     ViewProviderFemConstraintPulley = 'FemGui::ViewProviderFemConstraintPulley'
     ViewProviderFemConstraintPython = 'FemGui::ViewProviderFemConstraintPython'
+    ViewProviderFemConstraintSpring = 'FemGui::ViewProviderFemConstraintSpring'
     ViewProviderFemConstraintTemperature = 'FemGui::ViewProviderFemConstraintTemperature'
     ViewProviderFemConstraintTransform = 'FemGui::ViewProviderFemConstraintTransform'
     ViewProviderFemMesh = 'FemGui::ViewProviderFemMesh'
@@ -481,6 +483,7 @@ class Mesh:
     HarmonizeNormals = 'Mesh::HarmonizeNormals'
     Import = 'Mesh::Import'
     MeshObject = 'Mesh::MeshObject'
+    MeshSegment = 'Mesh::MeshSegment'
     PropertyCurvatureList = 'Mesh::PropertyCurvatureList'
     PropertyMeshKernel = 'Mesh::PropertyMeshKernel'
     PropertyNormalList = 'Mesh::PropertyNormalList'
